@@ -1,4 +1,4 @@
-/* Copyright (c) 2019-2023 Advanced Micro Devices, Inc.
+/* Copyright (c) 2019-2024 Advanced Micro Devices, Inc.
 
  Permission is hereby granted, free of charge, to any person obtaining a copy
  of this software and associated documentation files (the "Software"), to deal
@@ -377,6 +377,9 @@ wave_t::update (
       if (!architecture.are_trap_handler_ttmps_initialized (*this))
         architecture.initialize_trap_handler_ttmps (*this);
 
+      architecture.record_spi_ttmps_setup (
+        *this, agent ().spi_ttmps_setup_enabled ());
+
       write_register (amdgpu_regnum_t::wave_id, id ());
       m_ttmps_initialized = true;
     }
@@ -408,7 +411,9 @@ wave_t::update (
       && m_state == AMD_DBGAPI_WAVE_STATE_STOP)
     {
       /* Park the wave if the architecture does not support halting at certain
-         instructions.  */
+         instructions.  If the wave is loaded from a core dump, we do not park
+         the wave as there is no trap instruction to park the wave to, and
+         there is no need to park the wave in the first place either.  */
       if (architecture.park_stopped_waves (process ().rocr_rdebug_version ()))
         park ();
 
@@ -573,8 +578,8 @@ wave_t::set_state (amd_dbgapi_wave_state_t state,
                  | (agent ().exceptions ()
                     & os_exception_mask_t::device_memory_violation);
 
-        if (one_exception == AMD_DBGAPI_EXCEPTION_WAVE_APERTURE_VIOLATION)
-          return os_exception_mask_t::queue_wave_aperture_violation;
+        if (one_exception == AMD_DBGAPI_EXCEPTION_WAVE_ADDRESS_ERROR)
+          return os_exception_mask_t::queue_wave_address_error;
 
         dbgapi_assert_not_reached ("not a valid exception");
       };
@@ -1070,12 +1075,16 @@ amd_dbgapi_wave_stop (amd_dbgapi_wave_id_t wave_id)
     if ((wave = find (wave_id)) == nullptr)
       THROW (AMD_DBGAPI_STATUS_ERROR_INVALID_WAVE_ID);
 
+    if (wave->process ().is_frozen ())
+      THROW (AMD_DBGAPI_STATUS_ERROR_PROCESS_FROZEN);
+
     wave->set_state (AMD_DBGAPI_WAVE_STATE_STOP);
   }
   CATCH (AMD_DBGAPI_STATUS_ERROR_NOT_INITIALIZED,
          AMD_DBGAPI_STATUS_ERROR_INVALID_WAVE_ID,
          AMD_DBGAPI_STATUS_ERROR_WAVE_STOPPED,
-         AMD_DBGAPI_STATUS_ERROR_WAVE_OUTSTANDING_STOP);
+         AMD_DBGAPI_STATUS_ERROR_WAVE_OUTSTANDING_STOP,
+         AMD_DBGAPI_STATUS_ERROR_PROCESS_FROZEN);
   TRACE_END ();
 }
 
@@ -1096,6 +1105,9 @@ amd_dbgapi_wave_resume (amd_dbgapi_wave_id_t wave_id,
     if (wave == nullptr)
       THROW (AMD_DBGAPI_STATUS_ERROR_INVALID_WAVE_ID);
 
+    if (wave->process ().is_frozen ())
+      THROW (AMD_DBGAPI_STATUS_ERROR_PROCESS_FROZEN);
+
     if (resume_mode != AMD_DBGAPI_RESUME_MODE_NORMAL
         && resume_mode != AMD_DBGAPI_RESUME_MODE_SINGLE_STEP)
       THROW (AMD_DBGAPI_STATUS_ERROR_INVALID_ARGUMENT);
@@ -1105,7 +1117,7 @@ amd_dbgapi_wave_resume (amd_dbgapi_wave_id_t wave_id,
              | AMD_DBGAPI_EXCEPTION_WAVE_MATH_ERROR
              | AMD_DBGAPI_EXCEPTION_WAVE_ILLEGAL_INSTRUCTION
              | AMD_DBGAPI_EXCEPTION_WAVE_MEMORY_VIOLATION
-             | AMD_DBGAPI_EXCEPTION_WAVE_APERTURE_VIOLATION))
+             | AMD_DBGAPI_EXCEPTION_WAVE_ADDRESS_ERROR))
         != AMD_DBGAPI_EXCEPTION_NONE)
       THROW (AMD_DBGAPI_STATUS_ERROR_INVALID_ARGUMENT);
 
@@ -1142,7 +1154,8 @@ amd_dbgapi_wave_resume (amd_dbgapi_wave_id_t wave_id,
          AMD_DBGAPI_STATUS_ERROR_INVALID_ARGUMENT,
          AMD_DBGAPI_STATUS_ERROR_WAVE_NOT_STOPPED,
          AMD_DBGAPI_STATUS_ERROR_WAVE_NOT_RESUMABLE,
-         AMD_DBGAPI_STATUS_ERROR_RESUME_DISPLACED_STEPPING);
+         AMD_DBGAPI_STATUS_ERROR_RESUME_DISPLACED_STEPPING,
+         AMD_DBGAPI_STATUS_ERROR_PROCESS_FROZEN);
   TRACE_END ();
 }
 
